import type { AxiosInstance } from 'axios';
import request from '/@/utils/request';

export interface LogicSiteGetAllRes {
	ID: string;
	Name: string;
	Code: string;
	Paras: Record<string, unknown>;
	Flags: Record<string, unknown>[];
	TagName: string;
	UseStatus: number;
	SortCode: number;
	Description: string;
}

export interface LogicSitePostParams {
	Name: string;
	Code?: string;
	Paras?: Record<string, unknown>;
	Flags?: Record<string, unknown>[];
	TagName?: string;
	Description?: string;
}

/**
 * @summary 获取所有泵站
 */
export const GetAllPhmLogicSite = async (req: AxiosInstance = request) => {
	return req<LogicSiteGetAllRes>({
		url: '/Phm/Logic/Site/GetAll@V1.0',
		method: 'get',
	});
};

/**
 * @summary 添加一个泵站
 */
export const InsertAPhmLogicSite = async (data: LogicSitePostParams, req: AxiosInstance = request) => {
	return req<string>({
		url: '/Phm/Logic/Site/Insert@V1.0',
		method: 'post',
		data,
	});
};

/**
 * @summary 修改一个泵站
 */
export const UpdateAPhmLogicSite = async (data, req: any = request) => {
	return req({
		url: '/Phm/Logic/Site/Update@V1.0',
		method: 'put',
		data,
	});
};

/**
 * @summary 修改泵站排序码
 */
export const UpdatePhmLogicSiteSorter = async (data, req: any = request) => {
	return req({
		url: '/Phm/Logic/Site/UpdateSorter@V1.0',
		method: 'put',
		data,
	});
};

/**
 * @summary 更新泵站使用状态
 */
export const UpdatePhmLogicSiteUseStatus = async (data, req: any = request) => {
	return req({
		url: '/Phm/Logic/Site/UpdateUseStatus@V1.0',
		method: 'put',
		data,
	});
};

/**
 * @summary 检查是否已存在编码
 */
export const GetIsExistPhmLogicSiteCode = async (params, req: any = request) => {
	return req({
		url: '/Phm/Logic/Site/IsExistCode@V1.0',
		method: 'get',
		params,
	});
};

/**
 * @summary 检查是否已存在标记
 */
export const GetIsExistPhmLogicSiteTagName = async (params, req: any = request) => {
	return req({
		url: '/Phm/Logic/Site/IsExistTagName@V1.0',
		method: 'get',
		params,
	});
};

/**
 * @summary 删除一个泵站
 */
export const DeleteAPhmLogicSite = async (params, req: any = request) => {
	return req({
		url: '/Phm/Logic/Site/DeleteByID@V1.0',
		method: 'delete',
		params,
	});
};
